@@ -96,7 +96,7 @@ extern gotoblas_t gotoblas_BARCELONA;
 #endif
 #ifdef DYN_ATOM
 extern gotoblas_t gotoblas_ATOM;
-elif defined(DYN_NEHALEM)
+#elif defined(DYN_NEHALEM)
 #define gotoblas_ATOM gotoblas_NEHALEM
 #else
 #define gotoblas_ATOM gotoblas_PRESCOTT
@@ -855,7 +855,11 @@ static gotoblas_t *get_coretype(void){
 	    openblas_warning(FALLBACK_VERBOSE, BARCELONA_FALLBACK);
 	    return &gotoblas_BARCELONA; //OS doesn't support AVX. Use old kernels.
           }
-      } else if (exfamily == 10) {  
+      } else if (exfamily == 10) {
+	  if(support_avx512_bf16())
+	    return &gotoblas_COOPERLAKE;
+	  if(support_avx512())
+	    return &gotoblas_SKYLAKEX;
 	  if(support_avx())
 	    return &gotoblas_ZEN;
 	  else{
@@ -863,7 +867,7 @@ static gotoblas_t *get_coretype(void){
 	    return &gotoblas_BARCELONA; //OS doesn't support AVX. Use old kernels.
           }
       }else {
-	return &gotoblas_BARCELONA;
+	return NULL;
       }
    
     }
@@ -875,14 +879,37 @@ static gotoblas_t *get_coretype(void){
       if (model == 0xf && stepping < 0xe)
         return &gotoblas_NANO;
       return &gotoblas_NEHALEM;
+	case 0x7:
+      switch (exmodel) {
+      case 5:
+        if (support_avx2())
+          return &gotoblas_ZEN;
+        else
+          return &gotoblas_DUNNINGTON;
+      default:
+        return &gotoblas_NEHALEM;
+      }
     default:
-      if (family >= 0x7)
+      if (family >= 0x8)
         return &gotoblas_NEHALEM;
     }
   }
 
   if (vendor == VENDOR_ZHAOXIN) {
-      return &gotoblas_NEHALEM;
+    switch (family) {
+      case 0x7:
+        switch (exmodel) {
+        case 5:
+          if (support_avx2())
+            return &gotoblas_ZEN;
+          else
+            return &gotoblas_DUNNINGTON;
+        default:
+          return &gotoblas_NEHALEM;
+        }
+      default:
+        return &gotoblas_NEHALEM;
+    }
   }
 
   return NULL;
