@@ -118,10 +118,10 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
                         j += gvl;
                 }
                 v_res = VFREDMINVS_FLOAT(v_res, v_min, v_max, gvl);
-                minf = v_res[0];
+                minf = *((FLOAT*)&v_res);
                 mask = VMFLEVF_FLOAT(v_min, minf, gvl);
                 min_index = VMFIRSTM(mask,gvl);
-                min_index = v_min_index[min_index];
+                min_index = *((unsigned int*)&v_min_index+min_index);
 
                 if(j < n){
                         gvl = VSETVL(n-j);
@@ -131,7 +131,7 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
                         v_min = VFRSUBVF_MASK_FLOAT(mask, vx, vx, 0, gvl);
 
                         v_res = VFREDMINVS_FLOAT(v_res, v_min, v_max, gvl);
-                        FLOAT cur_minf = v_res[0];
+                        FLOAT cur_minf = *((FLOAT*)&v_res);
                         if(cur_minf < minf){
                                 //tail index
                                 v_min_index = VIDV_UINT(gvl);
@@ -139,7 +139,7 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
 
                                 mask = VMFLEVF_FLOAT(v_min, cur_minf, gvl);
                                 min_index = VMFIRSTM(mask,gvl);
-                                min_index = v_min_index[min_index];
+                                min_index = *((unsigned int*)&v_min_index+min_index);
                         }
                 }
         }else{
@@ -166,10 +166,10 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
                         idx += inc_v;
                 }
                 v_res = VFREDMINVS_FLOAT(v_res, v_min, v_max, gvl);
-                minf = v_res[0];
+                minf = *((FLOAT*)&v_res);
                 mask = VMFLEVF_FLOAT(v_min, minf, gvl);
                 min_index = VMFIRSTM(mask,gvl);
-                min_index = v_min_index[min_index];
+                min_index = *((unsigned int*)&v_min_index+min_index);
 
                 if(j < n){
                         gvl = VSETVL(n-j);
@@ -179,7 +179,7 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
                         v_min = VFRSUBVF_MASK_FLOAT(mask, vx, vx, 0, gvl);
 
                         v_res = VFREDMINVS_FLOAT(v_res, v_min, v_max, gvl);
-                        FLOAT cur_minf = v_res[0];
+                        FLOAT cur_minf = *((FLOAT*)&v_res);
                         if(cur_minf < minf){
                                 //tail index
                                 v_min_index = VIDV_UINT(gvl);
@@ -187,7 +187,7 @@ BLASLONG CNAME(BLASLONG n, FLOAT *x, BLASLONG inc_x)
 
                                 mask = VMFLEVF_FLOAT(v_min, cur_minf, gvl);
                                 min_index = VMFIRSTM(mask,gvl);
-                                min_index = v_min_index[min_index];
+                                min_index = *((unsigned int*)&v_min_index+min_index);
                         }
                 }
         }
