@@ -31,11 +31,12 @@ USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define VSETVL_MAX vsetvlmax_e32m1()
 #define FLOAT_V_T vfloat32m4_t
 #define FLOAT_V_T_M1 vfloat32m1_t
+#define VFMVFS_FLOAT vfmv_f_s_f32m1_f32
 #define VLEV_FLOAT vle_v_f32m4
 #define VLSEV_FLOAT vlse_v_f32m4
 #define VSEV_FLOAT vse_v_f32m4
 #define VSSEV_FLOAT vsse_v_f32m4
-#define VFREDSUM_FLOAT vfredsum_vs_f32m4_f32m1
+#define VFREDSUM_FLOAT vfredusum_vs_f32m4_f32m1
 #define VFMACCVV_FLOAT vfmacc_vv_f32m4
 #define VFMACCVF_FLOAT vfmacc_vf_f32m4
 #define VFMVVF_FLOAT vfmv_v_f_f32m4
@@ -46,11 +47,12 @@ USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define VSETVL_MAX vsetvlmax_e64m1()
 #define FLOAT_V_T vfloat64m4_t
 #define FLOAT_V_T_M1 vfloat64m1_t
+#define VFMVFS_FLOAT vfmv_f_s_f64m1_f64
 #define VLEV_FLOAT vle_v_f64m4
 #define VLSEV_FLOAT vlse_v_f64m4
 #define VSEV_FLOAT vse_v_f64m4
 #define VSSEV_FLOAT vsse_v_f64m4
-#define VFREDSUM_FLOAT vfredsum_vs_f64m4_f64m1
+#define VFREDSUM_FLOAT vfredusum_vs_f64m4_f64m1
 #define VFMACCVV_FLOAT vfmacc_vv_f64m4
 #define VFMACCVF_FLOAT vfmacc_vf_f64m4
 #define VFMVVF_FLOAT vfmv_v_f_f64m4
@@ -98,7 +100,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         i += gvl;
                                 }
                                 v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                temp2 = v_res[0];
+                                temp2 = VFMVFS_FLOAT(v_res);
                                 if(i < m){
                                         gvl = VSETVL(m-i);
                                         vy = VLEV_FLOAT(&y[i], gvl);
@@ -109,7 +111,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         vx = VLEV_FLOAT(&x[i], gvl);
                                         vr = VFMULVV_FLOAT(vx, va, gvl);
                                         v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                        temp2 += v_res[0];
+                                        temp2 += VFMVFS_FLOAT(v_res);
                                 }
 			}
                         y[j] += alpha * temp2;
@@ -143,7 +145,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         iy += inc_yv;
                                 }
                                 v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                temp2 = v_res[0];
+                                temp2 = VFMVFS_FLOAT(v_res);
                                 if(i < m){
                                         gvl = VSETVL(m-i);
                                         vy = VLSEV_FLOAT(&y[iy], stride_y, gvl);
@@ -154,7 +156,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         vx = VLEV_FLOAT(&x[i], gvl);
                                         vr = VFMULVV_FLOAT(vx, va, gvl);
                                         v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                        temp2 += v_res[0];
+                                        temp2 += VFMVFS_FLOAT(v_res);
                                 }
 			}
                         y[jy] += alpha * temp2;
@@ -189,7 +191,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         ix += inc_xv;
                                 }
                                 v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                temp2 = v_res[0];
+                                temp2 = VFMVFS_FLOAT(v_res);
                                 if(i < m){
                                         gvl = VSETVL(m-i);
                                         vy = VLEV_FLOAT(&y[i], gvl);
@@ -200,7 +202,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         vx = VLSEV_FLOAT(&x[ix], stride_x, gvl);
                                         vr = VFMULVV_FLOAT(vx, va, gvl);
                                         v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                        temp2 += v_res[0];
+                                        temp2 += VFMVFS_FLOAT(v_res);
                                 }
 			}
                         y[j] += alpha * temp2;
@@ -240,7 +242,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         iy += inc_yv;
                                 }
                                 v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                temp2 = v_res[0];
+                                temp2 = VFMVFS_FLOAT(v_res);
                                 if(i < m){
                                         gvl = VSETVL(m-i);
                                         vy = VLSEV_FLOAT(&y[iy], stride_y, gvl);
@@ -251,7 +253,7 @@ int CNAME(BLASLONG m, BLASLONG offset, FLOAT alpha, FLOAT *a, BLASLONG lda, FLOA
                                         vx = VLSEV_FLOAT(&x[ix], stride_x, gvl);
                                         vr = VFMULVV_FLOAT(vx, va, gvl);
                                         v_res = VFREDSUM_FLOAT(v_res, vr, v_z0, gvl);
-                                        temp2 += v_res[0];
+                                        temp2 += VFMVFS_FLOAT(v_res);
                                 }
 			}
                         y[jy] += alpha * temp2;
